==> arrow-docs-0.7.3-sources.jar: arrow/optics/Shape.Circle$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Shape`.`Circle`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Shape`.`Circle`, `kotlin`.`Double`> inline get()= arrow.optics.Iso(
  get = { circle: `arrow`.`optics`.`Shape`.`Circle` -> circle.radius },
  reverseGet = { `arrow`.`optics`.`Shape`.`Circle`(it) }
)

inline val `arrow`.`optics`.`Shape`.`Circle`.Companion.radius: arrow.optics.Lens<`arrow`.`optics`.`Shape`.`Circle`, `kotlin`.`Double`> inline get()= arrow.optics.Lens(
  get = { circle: `arrow`.`optics`.`Shape`.`Circle` -> circle.`radius` },
  set = { value: `kotlin`.`Double` ->
    { circle: `arrow`.`optics`.`Shape`.`Circle` ->
      circle.copy(`radius` = value)
    }
  }
)



inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Getter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Setter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Traversal<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Fold<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius

==> arrow-docs-0.9.0-sources.jar: arrow/optics/Shape.Circle$$optics.kt <==
package `arrow`.`optics`

import arrow.core.left
import arrow.core.right
import arrow.core.toOption

inline val `arrow`.`optics`.`Shape`.`Circle`.Companion.iso: arrow.optics.Iso<`arrow`.`optics`.`Shape`.`Circle`, `kotlin`.`Double`> inline get()= arrow.optics.Iso(
  get = { circle: `arrow`.`optics`.`Shape`.`Circle` -> circle.radius },
  reverseGet = { `arrow`.`optics`.`Shape`.`Circle`(it) }
)

inline val `arrow`.`optics`.`Shape`.`Circle`.Companion.radius: arrow.optics.Lens<`arrow`.`optics`.`Shape`.`Circle`, `kotlin`.`Double`> inline get()= arrow.optics.Lens(
  get = { circle: `arrow`.`optics`.`Shape`.`Circle` -> circle.`radius` },
  set = { circle: `arrow`.`optics`.`Shape`.`Circle`, value: `kotlin`.`Double` -> circle.copy(`radius` = value) }
)



inline val <S> arrow.optics.Iso<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Lens<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Lens<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Optional<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Prism<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Optional<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Getter<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Getter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Setter<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Setter<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Traversal<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Traversal<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
inline val <S> arrow.optics.Fold<S, `arrow`.`optics`.`Shape`.`Circle`>.radius: arrow.optics.Fold<S, `kotlin`.`Double`> inline get() = this + `arrow`.`optics`.`Shape`.`Circle`.radius
